@@ -1,5 +1,5 @@
 package HNS::Calendar::Direct;
-# $Id: Direct.pm,v 1.4 1999/11/23 15:56:28 tom Exp $
+# $Id: Direct.pm,v 1.5 2002/10/05 13:55:58 kenji Exp $
 ################################################################
 
 
@@ -29,7 +29,7 @@ sub AsHTML ($)
     my $self = shift;
     my $html;
 
-    $html = qq(<form action="index.cgi" method="get">);
+    $html = qq(<form action="$HNS::System::MyDiaryURI" method="get">);
     $html .= $self->SUPER::AsHTML($self->year, $self->month, $self->day, $SubmitLabel);
     $html .= qq(</form>);
     return $html;
