@@ -1,5 +1,5 @@
 package HNS::Hnf::Command;
-# $Id: Command.pm,v 1.39 2002/02/10 15:48:11 kenji Exp $
+# $Id: Command.pm,v 1.40 2005/10/04 10:14:38 kenji Exp $
 ################################################################
 
 =head1 NAME
@@ -262,7 +262,7 @@ use vars qw($BaseTemplate $NameTemplate $HrefTemplate
 @ISA = qw(HNS::Diary::Template);
 $HrefTemplate = "%base#%name";
 $Template{mydiary} = "%href";
-$Template{ISBN} = "http://www.bk1.co.jp/cgi-bin/srch/srch_result_book.cgi?idx=3&amp;isbn=%param";
+$Template{ISBN} = "http://www.bk1.co.jp/search/search.asp?kywd=%param";
 $Template{CD} = "http://www.hmv.co.jp/search/title.asp?category=CATALOGUENO&amp;keyword=%param";
 
 sub new($)
